@@ -1,2 +1,2 @@
 from .commonuicomponents import CommonUIComponents
-from .smartwidget import SmartWidget
+from .widgets import SmartWidget
